==> flowable-engine-6.1.0-sources.jar: org/flowable/engine/impl/cmd/IsProcessDefinitionSuspendedCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.flowable.engine.impl.cmd;

import java.io.Serializable;

import org.flowable.engine.compatibility.Flowable5CompatibilityHandler;
import org.flowable.engine.impl.interceptor.Command;
import org.flowable.engine.impl.interceptor.CommandContext;
import org.flowable.engine.impl.util.Flowable5Util;
import org.flowable.engine.impl.util.ProcessDefinitionUtil;

/**
 * @author Tijs Rademakers
 */
public class IsProcessDefinitionSuspendedCmd implements Command<Boolean>, Serializable {

    private static final long serialVersionUID = 1L;
    protected String processDefinitionId;

    public IsProcessDefinitionSuspendedCmd(String processDefinitionId) {
        this.processDefinitionId = processDefinitionId;
    }

    public Boolean execute(CommandContext commandContext) {
        // Backwards compatibility
        if (Flowable5Util.isFlowable5ProcessDefinitionId(commandContext, processDefinitionId)) {
            Flowable5CompatibilityHandler compatibilityHandler = Flowable5Util.getFlowable5CompatibilityHandler();
            return compatibilityHandler.isProcessDefinitionSuspended(processDefinitionId);
        }

        return ProcessDefinitionUtil.isProcessDefinitionSuspended(processDefinitionId);
    }
}

==> flowable-engine-6.3.0-sources.jar: org/flowable/engine/impl/cmd/IsProcessDefinitionSuspendedCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.flowable.engine.impl.cmd;

import java.io.Serializable;

import org.flowable.engine.common.impl.interceptor.Command;
import org.flowable.engine.common.impl.interceptor.CommandContext;
import org.flowable.engine.compatibility.Flowable5CompatibilityHandler;
import org.flowable.engine.impl.util.Flowable5Util;
import org.flowable.engine.impl.util.ProcessDefinitionUtil;

/**
 * @author Tijs Rademakers
 */
public class IsProcessDefinitionSuspendedCmd implements Command<Boolean>, Serializable {

    private static final long serialVersionUID = 1L;
    protected String processDefinitionId;

    public IsProcessDefinitionSuspendedCmd(String processDefinitionId) {
        this.processDefinitionId = processDefinitionId;
    }

    @Override
    public Boolean execute(CommandContext commandContext) {
        // Backwards compatibility
        if (Flowable5Util.isFlowable5ProcessDefinitionId(commandContext, processDefinitionId)) {
            Flowable5CompatibilityHandler compatibilityHandler = Flowable5Util.getFlowable5CompatibilityHandler();
            return compatibilityHandler.isProcessDefinitionSuspended(processDefinitionId);
        }

        return ProcessDefinitionUtil.isProcessDefinitionSuspended(processDefinitionId);
    }
}
